==> Alpha-0.7.4-src.tar.bz2: Alpha-0.7.4-src/Alpha/AlphaTabCtrl.h <==
// AlphaTabCtrl.h
// (c) 2003 exeal

#ifndef _ALPHA_TAB_CTRL_H_
#define _ALPHA_TAB_CTRL_H_
#include "..\Manah\TabCtrl.h"
#include "..\Manah\MenuOperator.h"
#include "..\Armaiti\ArmaitiImplementation.h"
using namespace Armaiti;


namespace Alpha {

// CAlphaTabCtrl class definition
/////////////////////////////////////////////////////////////////////////////

/**
 *	hbOAhhbvɑΉ\ȃ^uRg[
 *	Create ACreateEx ō쐬ɃTuNXsKv
 */
class CAlphaTabCtrl :
		public CTabCtrl,
		public IUnknownImpl<CUnheapMemoryManageModel>,
		public IDropSource,
		public IDropTarget {
	// \bh
public:
	bool		Create(HWND hwndParent, const RECT& rect, UINT nID);
	CPopupMenu*	GetContextMenu();

	// IUnknown C^[tFCX
	IMPLEMENT_UNKNOWN()
	BEGIN_INTERFACE_TABLE()
		IMPLEMENTS_LEFTMOST_INTERFACE(IDropSource)
		IMPLEMENTS_INTERFACE(IDropTarget)
	END_INTERFACE_TABLE()

	// IDropSource C^[tFCX
	STDMETHODIMP	QueryContinueDrag(BOOL fEscapePressed, DWORD grfKeyState);
	STDMETHODIMP	GiveFeedback(DWORD dwEffect);

	// IDropTarget C^[tFCX
	STDMETHODIMP	DragEnter(IDataObject* pDataObj, DWORD grfKeyState, POINTL pt, DWORD* pdwEffect);
	STDMETHODIMP	DragOver(DWORD grfKeyState, POINTL pt, DWORD* pdwEffect);
	STDMETHODIMP	DragLeave();
	STDMETHODIMP	Drop(IDataObject* pDataObj, DWORD grfKeyState, POINTL pt, DWORD* pdwEffect);

protected:
	LRESULT	DispatchEvent(UINT message, WPARAM wParam, LPARAM lParam);

	// f[^o
private:
	CPopupMenu	m_oContextMenu;	// ReLXgj[
};


///	ReLXgj[Ԃ
inline CPopupMenu* CAlphaTabCtrl::GetContextMenu() {
	return &m_oContextMenu;
}

}

#endif /* _ALPHA_TAB_CTRL_H_ */

/* [EOF] */

==> Alpha-0.7.5-src.tar.bz2: Alpha-0.7.5-src/Alpha/AlphaTabCtrl.h <==
// AlphaTabCtrl.h
// (c) 2003-2004 exeal

#ifndef _ALPHA_TAB_CTRL_H_
#define _ALPHA_TAB_CTRL_H_
#include "..\Manah\TabCtrl.h"
#include "..\Manah\MenuOperator.h"
#include "..\Armaiti\UnknownImpl.h"
using namespace Armaiti;


namespace Alpha {

// CAlphaTabCtrl class definition
/////////////////////////////////////////////////////////////////////////////

/**
 *	hbOAhhbvɑΉ\ȃ^uRg[
 *	Create ACreateEx ō쐬ɃTuNXsKv
 */
class CAlphaTabCtrl :
		public CTabCtrl,
		public IUnknownImpl<CUnheapMemoryManageModel>,
		public IDropSource,
		public IDropTarget {
	// \bh
public:
	bool		Create(HWND hwndParent, const RECT& rect, UINT nID);
	CPopupMenu*	GetContextMenu();

	// IUnknown C^[tFCX
	IMPLEMENT_UNKNOWN()
	BEGIN_INTERFACE_TABLE()
		IMPLEMENTS_LEFTMOST_INTERFACE(IDropSource)
		IMPLEMENTS_INTERFACE(IDropTarget)
	END_INTERFACE_TABLE()

	// IDropSource C^[tFCX
	STDMETHODIMP	QueryContinueDrag(BOOL fEscapePressed, DWORD grfKeyState);
	STDMETHODIMP	GiveFeedback(DWORD dwEffect);

	// IDropTarget C^[tFCX
	STDMETHODIMP	DragEnter(IDataObject* pDataObj, DWORD grfKeyState, POINTL pt, DWORD* pdwEffect);
	STDMETHODIMP	DragOver(DWORD grfKeyState, POINTL pt, DWORD* pdwEffect);
	STDMETHODIMP	DragLeave();
	STDMETHODIMP	Drop(IDataObject* pDataObj, DWORD grfKeyState, POINTL pt, DWORD* pdwEffect);

protected:
	LRESULT	DispatchEvent(UINT message, WPARAM wParam, LPARAM lParam);
	void	OnLButtonDblClk(UINT nFlags, POINT pt);	// WM_LBUTTONDBLCLK

	// f[^o
private:
	CPopupMenu	m_oContextMenu;	// ReLXgj[
};


///	ReLXgj[Ԃ
inline CPopupMenu* CAlphaTabCtrl::GetContextMenu() {
	return &m_oContextMenu;
}

}

#endif /* _ALPHA_TAB_CTRL_H_ */

/* [EOF] */
